#
# spec file for package python-tld
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-tld
Version:        0.9.2
Release:        2.1
Summary:        URL top level domain (TLD) extraction module
License:        MPL-1.1 OR GPL-2.0-only OR LGPL-2.1-only
Group:          Development/Languages/Python
Url:            https://github.com/barseghyanartur/tld
Source:         https://files.pythonhosted.org/packages/source/t/tld/tld-%{version}.tar.gz
# PATCH-FIX-OPENSUSE remove-download-test.patch
Patch0:         remove-download-test.patch
BuildRequires:  %{python_module setuptools}
BuildRequires:  python-rpm-macros
# SECTION test requirements
BuildRequires:  %{python_module six >= 1.9}
# /SECTION
BuildRequires:  fdupes
Requires:       python-six >= 1.9
BuildArch:      noarch

%python_subpackages

%description
This module extracts the top level domain (TLD) from the URL given.
A list of TLD names is taken from Mozillas public suffix list:
<https://publicsuffix.org/list/effective_tld_names.dat>

%prep
%setup -q -n tld-%{version}
sed -i '1s/^#!.*/#!\/usr\/bin\/python3/' src/tld/bin/update-tld-names
%patch0 -p1

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%{python_expand chmod -x %{buildroot}%{$python_sitelib}/tld/res/old/effective_tld_names-2015-07-19.dat.txt}

%check
%python_exec setup.py test

%files %{python_files}
%doc README.rst CHANGELOG.rst
%license LICENSE_GPL2.0.txt LICENSE_LGPL_2.1.txt
%python3_only %{_bindir}/update-tld-names
%{python_sitelib}/*

%changelog
* Wed Jan 23 2019 jengelh@inai.de
- Use noun phrase.
* Tue Jan 15 2019 sebix+novell.com@sebix.at
- Update to version 0.9.2:
  * Fix an issue causing certain punycode TLDs to be deemed invalid.
  * Tested against Python 3.7.
  * Added tests for commands.
  * Dropped Python 2.6 support.
  * TLD source updated to the latest version.
- Update and extend remove-download-test.patch
* Tue Dec  4 2018 mcepl@suse.com
- Remove superfluous devel dependency for noarch package
* Mon Jul  9 2018 sebix+novell.com@sebix.at
- remove fix-setup-test.patch, merged upstream
- update to version 0.9.1:
  * Correctly handling nested TLDs.
- update to version 0.9:
  * This release contains backward incompatible changes. You should update your code.
  * The active_only option has been removed from get_tld, get_fld and parse_url functions. Update your code accordingly.
  * Removed active_only option from get_tld, get_fld and parse_url functions.
  * Correctly handling exceptions (!) in the original TLD list.
  * Fixes in documentation.
  * Added parse_tld function.
  * Fixes the python setup.py test command.
* Fri Jul  6 2018 sebix+novell.com@sebix.at
- add remove-download-test.patch to remove download test requiring internet
- add fix-setup-test.patch to fix setup.py test_suite specifier
- update to version 0.8:
  - This release contains backward incompatible changes. You should update
  your code.
  Old `get_tld` functionality remain is moved to `get_fld` (first-level
  domain definition). The `as_object` argument (False by default) has been
  deprecated for `get_fld`.
  Have a look at the packages' documentation and changelog for details and examples.
  - Move to a Trie to match TLDs. This brings a speed up of 15-20%%.
  - It's now possible to search in public, private or all suffixes (old
  behaviour). Use `search_public` and `search_private` arguments accordingly.
  By default (to support old behavior), both are set to True.
  - Correct TLD definitions.
  - Domains like `*****.xn--fiqs8s` are now recognized as well.
  - Due to usage of `urlsplit` instead of `urlparse`, the initial list of TLDs
  is assembled quicker (a speed-up of 15-20%%).
  - Docs/ directory is included in source distribution tarball.
* Sat Apr  7 2018 sebix+novell.com@sebix.at
- update to version 0.7.10:
  * more documentation files included
  * included license file
  * update tld data
* Thu Dec  7 2017 sebix+novell.com@sebix.at
- initial package for version 0.7.9
